document.getElementById("Contents").innerHTML='\
    <ul><li><input type="checkbox" id="07"><label for="07">Makroar og skriptlaging</label><ul>\
    <li><input type="checkbox" id="0701"><label for="0701">Generell informasjon og bruk av brukargrensesnittet</label><ul>\
    <li><a target="_top" href="nn/text/sbasic/shared/main0601.html">Hjelp for LibreOffice Basic</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01000000.html">Programmering i LibreOffice Basic</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/00000002.html">Ordliste for LibreOffice</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01010210.html">Grunnleggjande</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01020000.html">Syntaks</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01050000.html">LibreOffice Basic IDE</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01030100.html">IDE-oversikt</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01030200.html">Redigeringsvindauget for Basic</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01050100.html">Overvakingsvindauget</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/main0211.html">Makroverktøylinja</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/05060700.html">Makro</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/vbasupport.html">Støtte for VBA-makroar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0702"><label for="0702">Kommandoreferanse</label><ul>\
    <li><a target="_top" href="nn/text/sbasic/shared/01020300.html">Bruk av prosedyrar og funksjonar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01020500.html">Bibliotek, modular og dialogvindauge</a></li>\
    <li><input type="checkbox" id="070202"><label for="070202">Funksjonar, uttrykk og operatorar</label><ul>\
    <li><a target="_top" href="nn/text/sbasic/shared/03010000.html">I/O-funksjonar for skjerm</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020000.html">I/O-funksjonar for filer</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030000.html">Dato- og klokkeslettfunksjonar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03050000.html">Funksjonar for feilhandtering</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03060000.html">Logiske operatorar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03070000.html">Matematiske operatorar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080000.html">Numeriske funksjonar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090000.html">Kontrollera programkøyringa</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100000.html">Variablar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03040000.html">Basic-konstantar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03110000.html">Samanlikningsoperatorar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120000.html">Strengar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/special_vba_func.html">Eksklusive VBA-funksjonar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03130000.html">Andre kommandoar</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070201"><label for="070201">Alfabetisk liste over funksjonar, uttrykk, og operatorar</label><ul>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080601.html">Abs-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03060100.html">AND-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03104200.html">Matrisefunksjon</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120101.html">Asc-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120111.html">AscW-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080101.html">Atn-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03130100.html">Beep-uttrykkket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03010301.html">Blue-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100100.html">CBool-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120105.html">CByte-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100050.html">CCur-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030116.html">CDateFromUnoDateTime-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030115.html">CDateToUnoDateTime-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030114.html">CDateFromUnoTime-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030113.html">CDateToUnoTime-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030112.html">CDateFromUnoDate-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030111.html">CDateToUnoDate-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030108.html">CDateFromIso-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030107.html">CDateToIso-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100300.html">CDate-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100400.html">CDbl-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100060.html">CDec-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100500.html">CInt-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100600.html">CLng-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100900.html">CSng-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03101000.html">CStr-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090401.html">Call-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020401.html">ChDir-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020402.html">ChDrive-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090402.html">Choose-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120102.html">Chr-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120112.html">ChrW-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020101.html">Close-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03110100.html">Samanlikningsoperatorar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100700.html">Const-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120313.html">ConvertFromURL-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120312.html">ConvertToURL-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080102.html">Cos-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03132400.html">CreateObject-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03131800.html">CreateUnoDialog-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03132000.html">CreateUnoListener-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03131600.html">CreateUnoService-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03131500.html">CreateUnoStruct-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03132300.html">CreateUnoValue-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020403.html">CurDir-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100070.html">CVar-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03100080.html">CVErr-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030110.html">DateAdd-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030120.html">DateDiff-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030130.html">DatePart-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030101.html">DateSerial-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030102.html">DateValue-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030301.html">Date-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030103.html">Day-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140000.html">DDB-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090403.html">Declare-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03101100.html">DefBool-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03101300.html">DefDate-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03101400.html">DefDbl-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03101500.html">DefInt-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03101600.html">DefLng-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03101700.html">DefObj-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03102000.html">DefVar-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03104300.html">DimArray-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03102100.html">Dim-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020404.html">Dir-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090201.html">Do...Loop-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03110100.html">Samanlikningsoperatorar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090404.html">End-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03130800.html">Environ-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020301.html">Eof-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03104600.html">EqualUnoObjects-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03060200.html">Eqv-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03050100.html">Erl-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03050200.html">Err-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03050300.html">Error-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03050000.html">Funksjonar for feilhandtering</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090412.html">Exit-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080201.html">Exp-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020405.html">FileAttr-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020406.html">FileCopy-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020407.html">FileDateTime-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020415.html">FileExists-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020408.html">FileLen-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103800.html">FindObject-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103900.html">FindPropertyObject-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080501.html">Fix-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090202.html">For...Next-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120301.html">Format-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03150000.html">FormatDateTime-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03170010.html">FormatNumber-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020102.html">FreeFile-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090405.html">FreeLibrary-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090406.html">Function-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090400.html">Andre uttrykk</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140001.html">FV-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080300.html">Laga tilfeldige tal</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020409.html">GetAttr-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03132500.html">GetDefaultContext-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03132100.html">GetGuiType-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03131700.html">GetProcessServiceManager-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03131000.html">GetSolarVersion-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03130700.html">GetSystemTicks-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020201.html">Get-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03131900.html">GlobalScope</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090301.html">GoSub...Return-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090302.html">GoTo-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03010302.html">Green-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03104400.html">HasUnoInterfaces-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080801.html">Hex-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030201.html">Hour-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090103.html">IIf-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090101.html">If...Then...Else-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03060300.html">Imp-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120401.html">InStr-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120411.html">InStrRev-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03160000.html">Input-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03010201.html">InputBox-funksjon</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020202.html">Input#-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080502.html">Int-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140002.html">IPmt-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140003.html">IRR-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03102200.html">IsArray-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03102300.html">IsDate-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03102400.html">IsEmpty-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03104000.html">IsMissing-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03102600.html">IsNull-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03102700.html">IsNumeric-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03102800.html">IsObject-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03104500.html">IsUnoStruct-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120315.html">Join-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020410.html">Kill-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03102900.html">LBound-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120302.html">LCase-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120304.html">LSet-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120305.html">LTrim-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120303.html">Left-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120402.html">Len-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103100.html">Let-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020203.html">Line Input # uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020302.html">Loc-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020303.html">Lof-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080202.html">Log-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120306.html">Mid-funksjonen, Mid-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030202.html">Minute-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140004.html">MIRR-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020411.html">MkDir-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03070600.html">Mod-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030104.html">Month-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03150002.html">MonthName-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03010102.html">MsgBox-funksjon</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03010101.html">MsgBox-uttrykk</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020412.html">Name-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03060400.html">Not-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030203.html">Now-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140005.html">NPer-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140006.html">NPV-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080000.html">Numeriske funksjonar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080802.html">Oct-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03050500.html">On Error GoTo ... Resume-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090303.html">On...GoSub Statement; On...GoTo uttrykk</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020103.html">Open-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103200.html">Option Base-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103300.html">Option Explicit-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103350.html">Option VBASupport-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03104100.html">Optional (i funksjonsuttrykk)</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03060500.html">Or-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140007.html">Pmt-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140008.html">PPmt-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140009.html">PV-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03010103.html">Print-uttrykk</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103400.html">Public-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020204.html">Put-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03010304.html">QBColor-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140010.html">Rate-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03010305.html">RGB-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120308.html">RSet-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120309.html">RTrim-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080301.html">Randomize-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03102101.html">ReDim-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03010303.html">Red-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090407.html">Rem-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020104.html">Reset-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120307.html">Right-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020413.html">RmDir-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080302.html">Rnd-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03170000.html">Round-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030204.html">Second-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020304.html">Seek-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020305.html">Seek-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090102.html">Select...Case-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020414.html">SetAttr-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103700.html">Set-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080701.html">Sgn-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03130500.html">Shell-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080103.html">Sin-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140011.html">SLN-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120201.html">Space-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120314.html">Split-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080401.html">Sqr-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080400.html">Utrekning av kvadratrot</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103500.html">Static-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090408.html">Stop-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120403.html">StrComp-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120103.html">Str-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120412.html">StrReverse-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120202.html">String-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090409.html">Sub-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090410.html">Switch-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03140012.html">SYD-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080104.html">Tan-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030205.html">TimeSerial-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030206.html">TimeValue-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030302.html">Time-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030303.html">Timer-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03080100.html">Trigonometriske funksjonar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120311.html">Trim-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03131300.html">TwipsPerPixelX-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03131400.html">TwipsPerPixelY-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090413.html">Type-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103600.html">TypeName-funksjonen; VarType-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03103000.html">UBound-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120310.html">UCase-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03120104.html">Val-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03130600.html">Wait-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030105.html">WeekDay-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03150001.html">WeekdayName-funksjonen [VBA]</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090203.html">While...Wend-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03090411.html">With-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03020205.html">Write-uttrykket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03060600.html">XOR-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03030106.html">Year-funksjonen</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03070100.html">«-»-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03070200.html">«*»-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03070300.html">«+»-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03070400.html">«/»-operatoren</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03070500.html">«^»-operatoren</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="070205"><label for="070205">Avanserte Basic-bibliotek</label><ul>\
    <li><a target="_top" href="nn/text/sbasic/shared/03/lib_tools.html">Tools-bibliotek</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03/lib_depot.html">DEPOT-bibliotek</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03/lib_euro.html">EURO-biblioteket</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03/lib_formwizard.html">FORMWIZARD-bibliotek</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03/lib_gimmicks.html">GIMMICKS-bibliotek</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03/lib_schedule.html">SCHEDULE-bibliotek</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03/lib_script.html">SCRIPTBINDINGLIBRARY-bibliotek</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/03/lib_template.html">TEMPLATE-bibliotek</a></li>\
			</ul></li>\
                    </ul></li>\
    <li><input type="checkbox" id="0703"><label for="0703">Hjelpelinjer</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/macro_recording.html">Opptak av makro</a></li>\
    <li><a target="_top" href="nn/text/sbasic/guide/control_properties.html">Endra eigenskapane for kontrollar i dialogredigeringa</a></li>\
    <li><a target="_top" href="nn/text/sbasic/guide/insert_control.html">Setja inn kontrollelement i dialogvindauget</a></li>\
    <li><a target="_top" href="nn/text/sbasic/guide/sample_code.html">Programmeringseksempel for kontrollelementa</a></li>\
    <li><a target="_top" href="nn/text/sbasic/guide/show_dialog.html">Opna eit dialogvindauge med programkode</a></li>\
    <li><a target="_top" href="nn/text/sbasic/guide/create_dialog.html">Laga eit dialogvindauge i Basic</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01030400.html">Organisera bibliotek og modular</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01020100.html">Å bruka variablar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01020200.html">Bruk av objekt (object)</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01030300.html">Feilsøking i eit Basic-program</a></li>\
    <li><a target="_top" href="nn/text/sbasic/shared/01040000.html">Hendingsdrivne makroar</a></li>\
    <li><a target="_top" href="nn/text/sbasic/guide/access2base.html">Access2Base</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="08"><label for="08">Rekneark (Calc)</label><ul>\
    <li><input type="checkbox" id="0801"><label for="0801">Generell informasjon og bruk av brukargrensesnittet</label><ul>\
    <li><a target="_top" href="nn/text/scalc/main0000.html">Velkommen til hjelp for LibreOffice Calc</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0503.html">LibreOffice Calc-funksjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/keyboard.html">Snartastar (tilgjengelege i LibreOffice Calc)</a></li>\
    <li><a target="_top" href="nn/text/scalc/04/01020000.html">Snartastar for rekneark</a></li>\
    <li><a target="_top" href="nn/text/scalc/05/02140000.html">Feilkoder i LibreOffice Calc</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060112.html">Tillegg for programmering i LibreOffice Calc</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/main.html">Hjelp til bruk av LibreOffice Calc</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0802"><label for="0802">Kommando og menyreferanse</label><ul>\
    <li><input type="checkbox" id="080201"><label for="080201">Menyar</label><ul>\
    <li><a target="_top" href="nn/text/scalc/main0100.html">Menyar</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0101.html">Fil</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0102.html">Rediger</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0103.html">Vis</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0104.html">Set inn</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0105.html">Format</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0116.html">Ark</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0112.html">Data</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0106.html">Verktøy</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0107.html">Vindauge</a></li>\
    <li><a target="_top" href="nn/text/shared/main0108.html">Hjelp</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="080202"><label for="080202">Verktøylinjer</label><ul>\
    <li><a target="_top" href="nn/text/scalc/main0200.html">Verktøylinjer</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0202.html">Formateringslinja</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0203.html">Linja </a></li>\
    <li><a target="_top" href="nn/text/scalc/main0205.html">Tekstformateringslinja</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0206.html">Formellinja</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0208.html">Statuslinja</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0210.html">Linja for førehandsvising av sida</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0214.html">Biletlinje</a></li>\
    <li><a target="_top" href="nn/text/scalc/main0218.html">Verktøylinja</a></li>\
    <li><a target="_top" href="nn/text/shared/main0201.html">Standardlinje</a></li>\
    <li><a target="_top" href="nn/text/shared/main0212.html">Tabelldatalinja</a></li>\
    <li><a target="_top" href="nn/text/shared/main0213.html">Navigasjonslinja for skjema</a></li>\
    <li><a target="_top" href="nn/text/shared/main0214.html">Verktøylinja for spørjingsutforming</a></li>\
    <li><a target="_top" href="nn/text/shared/main0226.html">Verktøylinja for skjemautforming</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0803"><label for="0803">Funksjonstypar og operatorar</label><ul>\
    <li><a target="_top" href="nn/text/scalc/01/04060000.html">Funksjonsvegvisar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060100.html">Funksjonar etter kategori</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060107.html">Matrisefunksjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060120.html">Funksjonar for bitoperasjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060101.html">Databasefunksjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060102.html">Funksjonar for dato og klokkeslett</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060103.html">Finansfunksjonar del ein</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060119.html">Finansfunksjonar del to</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060118.html">Finansfunksjonar del tre</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060104.html">Informasjonsfunksjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060105.html">Logiske funksjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060106.html">Matematiske funksjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060108.html">Statistikkfunksjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060181.html">Statistiske funksjonar del to</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060182.html">Statistiske funksjonar del to</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060183.html">Statistiske funksjonar del tre</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060184.html">Statistiske funksjonar del fire</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060185.html">Statistiske funksjonar del fire</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060109.html">Reknearksfunksjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060110.html">Tekstfunksjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060111.html">Tilleggsfunksjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060115.html">Tilleggsfunksjonar, lista over analysefunksjonar del ein</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060116.html">Tilleggsfunksjonar, liste over analysefunksjonar del to</a></li>\
    <li><a target="_top" href="nn/text/scalc/01/04060199.html">Operatorar i LibreOffice Calc</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/userdefined_function.html">Sjølvvalde funksjonar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0804"><label for="0804">Innlasting, lagring, importera og eksportera</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/webquery.html">Setja inn eksterne data i tabellar (nettspørjingar)</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/html_doc.html">Lagra og opna ark i HTML</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/csv_formula.html">Importera og eksportera tekstfier</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0805"><label for="0805">Formatering</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/text_rotate.html">Rotera tekst</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/text_wrap.html">Skrive tekst med fleire linjer</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/text_numbers.html">Formatera tal som tekst</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/super_subscript.html">Heva og senka skrift</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/row_height.html">Endre radhøgd og kolonnebreidd</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/cellstyle_conditional.html">Bruka vilkårsformatering</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/cellstyle_minusvalue.html">Utheva negative tal</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/cellstyle_by_formula.html">Tildel format med formlar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/integer_leading_zero.html">Skriv inn eit tal med innleiande nullar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/format_table.html">Formatera rekneark</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/format_value.html">Formatera tal med desimalar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/value_with_name.html">Namngje celler</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/table_rotate.html">Rotere tabellar (omstille)</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/rename_table.html">Endra arknamn</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/year2000.html">19xx/20xx-år</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/rounding_numbers.html">Bruka avrunda tal</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/currency_format.html">Celler i valutaformat</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/autoformat.html">Bruka autoformatering på tabellar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/note_insert.html">Slik set du inn og redigerer merknadar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/design.html">Velja tema for ark</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/fraction_enter.html">Innskriving av brøkar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0806"><label for="0806">Filtrering og sortering</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/filters.html">Bruk filter</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/specialfilter.html">Filter: Bruka avanserte filter</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/autofilter.html">Bruka autofiltrering</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/sorted_list.html">Bruka sorteringslister</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0807"><label for="0807">Utskriving</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/print_title_row.html">Skrive ut rader eller kolonnar på kvar side</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/print_landscape.html">Skrive ut rekneark liggjande</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/print_details.html">Skrive ut rekneark</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/print_exact.html">Skriv talet på sider som skal skrivast ut</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0808"><label for="0808">Dataområde</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/database_define.html">Definer databaseområde</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/database_filter.html">Filtrere celleområde</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/database_sort.html">Sortere data</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0809"><label for="0809">Pivottabell</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/datapilot.html">Pivottabell</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/datapilot_createtable.html">Å lage pivottabellar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/datapilot_deletetable.html">Sletting av pivottabellar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/datapilot_edittable.html">Redigera pivottabellar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/datapilot_filtertable.html">Filtrere pivottabellar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/datapilot_tipps.html">Vel utområdet for pivottabellen</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/datapilot_updatetable.html">Oppdatere pivottabellar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="08091"><label for="08091">Pivotdiagram</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/pivotchart.html">Pivotdiagram</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/pivotchart_create.html">Slik lagar du pivotdiagram</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/pivotchart_edit.html">Redigere pivottabellar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/pivotchart_filter.html">Filtrere pivotdiagram</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/pivotchart_update.html">Oppdatera ein pivottabell</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/pivotchart_delete.html">Sletting av pivotdiagram</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="0810"><label for="0810">Scenarier</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/scenario.html">Bruka scenario</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0811"><label for="0811">Referansar</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/relativ_absolut_ref.html">Adresser og referansar, absolutte og relative</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/cellreferences.html">Referere til ei celle i eit anna dokument</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/cellreferences_url.html">Referansar til andre ark og referansar til nettadresser</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/cellreference_dragdrop.html">Referere til celler ved å dra og sleppe</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/address_auto.html">Bruka namn som adresser</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0812"><label for="0812">Vising, val og kopiering</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/table_view.html">Endre tabellvising</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/formula_value.html">Å vise formlar eller verdiar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/line_fix.html">Fryse rader eller kolonnar som overskrifter</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/multi_tables.html">Navigera gjennom arkfaner</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/edit_multitables.html">Kopiere til fleire ark</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/cellcopy.html">Berre kopier synlege celler</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/mark_cells.html">Markera fleire celler</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0813"><label for="0813">Formlar og utrekningar</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/formulas.html">Å rekne med formlar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/formula_copy.html">Kopiere formlar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/formula_enter.html">Skrive inn formlar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/formula_value.html">Å vise formlar eller verdiar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/calculate.html">Utrekningar i rekneark</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/calc_date.html">Utrekningar med datoar og klokkeslett</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/calc_series.html">Rekna ut seriar automatisk</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/calc_timevalues.html">Rekna ut tidsskilnader</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/matrixformula.html">Skrive inn matriseformlar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0814"><label for="0814">Vern</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/cell_protect.html">Vern celler mot endringar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/cell_unprotect.html">Opphev cellevern</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0815"><label for="0815">Forskjellig</label><ul>\
    <li><a target="_top" href="nn/text/scalc/guide/auto_off.html">Slå av automatiske endringar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/consolidate.html">Slå saman data</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/goalseek.html">Å tilpasse verdiar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/multioperation.html">Bruka fleire operasjonar</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/multitables.html">Bruka fleire ark</a></li>\
    <li><a target="_top" href="nn/text/scalc/guide/validity.html">Validiteten av celleinnhald</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="05"><label for="05">Grafar og diagram</label><ul>\
    <li><input type="checkbox" id="0501"><label for="0501">Generell informasjon</label><ul>\
    <li><a target="_top" href="nn/text/schart/main0000.html">Diagram i LibreOffice</a></li>\
    <li><a target="_top" href="nn/text/schart/main0503.html">LibreOffice Chart-funksjonar</a></li>\
    <li><a target="_top" href="nn/text/schart/04/01020000.html">Snartastar for diagram</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice Innstallering</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/ms_doctypes.html">Endra filtilknyting for Microsoft Office-dokumenttypar</a></li>\
    <li><a target="_top" href="nn/text/shared/01/profile_safe_mode.html">Sikker modus</a></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="10"><label for="10">Vanlege emne i hjelp</label><ul>\
    <li><input type="checkbox" id="1001"><label for="1001">Generell informasjon</label><ul>\
    <li><a target="_top" href="nn/text/shared/main0400.html">Snartastar</a></li>\
    <li><a target="_top" href="nn/text/shared/00/00000005.html">Generell ordliste</a></li>\
    <li><a target="_top" href="nn/text/shared/00/00000002.html">Ordliste over Internett-termar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/accessibility.html">Tilgjenge i LibreOffice</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/keyboard.html">Snøggtastar (tilgjenge i LibreOffice)</a></li>\
    <li><a target="_top" href="nn/text/shared/04/01010000.html">Generelle snartastar i LibreOffice</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/version_number.html">Versjonar og utgjevingsnummer</a></li>\
</ul></li>\
    <li><input type="checkbox" id="1002"><label for="1002">LibreOffice og Microsoft Office</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/ms_user.html">Bruka Microsoft Office og LibreOffice</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/microsoft_terms.html">Samanlikning av termar i Microsoft Office og LibreOffice</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/ms_import_export_limitations.html">Om konvertering av Microsoft Office-dokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/ms_doctypes.html">Endra filtilknyting for Microsoft Office-dokumenttypar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1004"><label for="1004">LibreOffice-innstillingar</label><ul>\
    <li><a target="_top" href="nn/text/shared/optionen/01000000.html">Innstillingar</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01010100.html">Brukarinformasjon</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01010200.html">Generelt</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01010300.html">Stiar</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01010400.html">Skrivestøtte</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01010600.html">Generelt</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01010700.html">Skrifttypar</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01010800.html">Vis</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01010900.html">Utskriftsval</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01012000.html">Programfargar</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01013000.html">Tilgjenge</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/java.html">Avansert</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/expertconfig.html">Avanserte innstillingar</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/persona_firefox.html">Personleg tilpassing</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/BasicIDE.html">Basic IDE</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/opencl.html">Open CL</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01020000.html">Val for innlasting/lagring</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01030000.html">Innstillingar for Internett</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01040000.html">Tekstdokument</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01050000.html">Tekstdokument</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01060000.html">Innstillingar for rekneark</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01070000.html">Innstillingar for presentasjonar</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01080000.html">Innstillingar for teikning</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01090000.html">Formel</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01110000.html">Innstillingar for diagram</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01130100.html">VBA-eigenskapar</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01130200.html">MS Office</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01140000.html">Språk</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01150000.html">Alternativ for språkinnstillingar</a></li>\
    <li><a target="_top" href="nn/text/shared/optionen/01160000.html">Innstillingar for datakjelder</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1005"><label for="1005">Vegvisarar</label><ul>\
    <li><a target="_top" href="nn/text/shared/autopi/01000000.html">Vegvisar</a></li>\
    <li><input type="checkbox" id="100501"><label for="100501">Vegvisar for brev</label><ul>\
    <li><a target="_top" href="nn/text/shared/autopi/01010000.html">Vegvisar for brev</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100502"><label for="100502">Faks-vegvisar</label><ul>\
    <li><a target="_top" href="nn/text/shared/autopi/01020000.html">Faks-vegvisar</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100504"><label for="100504">Møteplanvegvisar</label><ul>\
    <li><a target="_top" href="nn/text/shared/autopi/01040000.html">Møteplanvegvisar</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100506"><label for="100506">Vegvisar for HTML-eksport</label><ul>\
    <li><a target="_top" href="nn/text/shared/autopi/01110000.html">HTML-eksport</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="100510"><label for="100510">Vegvisar for dokumentkonvertering</label><ul>\
    <li><a target="_top" href="nn/text/shared/autopi/01130000.html">Dokumentkonvertering</a></li>\
			</ul></li>\
    <li><a target="_top" href="nn/text/shared/autopi/01150000.html">Vegvisar for Euro-omreknaren</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1006"><label for="1006">Oppsett av LibreOffice</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/configure_overview.html">Setja opp LibreOffice</a></li>\
    <li><a target="_top" href="nn/text/shared/01/packagemanager.html">Utvidingar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/flat_icons.html">Endra ikonvisingar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/edit_symbolbar.html">Leggja til knappar på verktøylinjer</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/workfolder.html">Byta arbeidsmappe</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/standard_template.html">Endra standardmalane</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_addressbook.html">Registrera ei adressebok</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/formfields.html">Setja inn og redigera knappar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1007"><label for="1007">Arbeida med brukargrensesnittet</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/navigator_setcursor.html">Bruka dokumentstruktur for å koma raskt til objekt</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/navigator.html">Dokumentstruktur</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/autohide.html">Visa, festa og gøyma vindauge</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/navpane_on.html">Visa navigasjonspanelet i Hjelp</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/textmode_change.html">Byte mellom innsetjingstilstand og overskrivingstilstand</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/floating_toolbar.html">Bruka verktøylinjer</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="10071"><label for="10071">Digitale signaturar</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/digital_signatures.html">Om digitale signaturar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/digitalsign_send.html">Leggja til digitale signaturar</a></li>\
    <li><a target="_top" href="nn/text/shared/01/digitalsignaturespdf.html">Digital signatur i PDF-eksport</a></li>\
    <li><a target="_top" href="nn/text/shared/01/signexistingpdf.html">Underskriving av eksisterande PDF...</a></li>\
    <li><a target="_top" href="nn/text/swriter/01/addsignatureline.html">Leggja til ei signaturlinje i tekstdokument</a></li>\
    <li><a target="_top" href="nn/text/swriter/01/signsignatureline.html">Underskriving av signaturlinja</a></li>\
                </ul></li>\
    <li><input type="checkbox" id="1008"><label for="1008">Utskrift, faks, sending</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/labels_database.html">Skriva ut adresseetikettar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/print_blackwhite.html">Skriva ut i svart-kvitt</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/email.html">Senda dokument som e-postvedlegg</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/fax.html">Senda faksar og setja opp LibreOffice for faksing</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1009"><label for="1009">Dra og slepp</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/dragdrop.html">Dra og sleppa i eit LibreOffice-dokument</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/dragdroptext.html">Flytta og kopiera tekst i dokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/dragdrop_table.html">Kopiera reknearksområde til tekstdokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/dragdrop_graphic.html">Kopiera bilete mellom dokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/dragdrop_fromgallery.html">Kopiera bilete frå galleriet</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/dragdrop_beamer.html">Dra og sleppa i datakjeldevisinga</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1010"><label for="1010">Kopier og lim inn</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/copy_drawfunctions.html">Kopiera teikneobjekt til andre dokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/dragdrop_graphic.html">Kopiera bilete mellom dokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/dragdrop_fromgallery.html">Kopiera bilete frå galleriet</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/dragdrop_table.html">Kopiera reknearksområde til tekstdokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1012"><label for="1012">Grafar og diagram</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/chart_insert.html">Setja inn diagram</a></li>\
    <li><a target="_top" href="nn/text/schart/main0000.html">Diagram i LibreOffice</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1013"><label for="1013">Opna, lagra, importer, eksporter</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/doc_open.html">Opna dokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/import_ms.html">Opna dokument lagra i andre format</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/doc_save.html">Lagra dokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/doc_autosave.html">Lagra dokument automatisk</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/export_ms.html">Lagra dokument i andre format</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_dbase2office.html">Importera og eksportera data i tekstformat</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1014"><label for="1014">Lenkjer og referansar</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/hyperlink_insert.html">Setja inn hyperlenkjer</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/hyperlink_rel_abs.html">Relative og absolutte lenkjer</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/hyperlink_edit.html">Redigera hyperlenkjer</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1015"><label for="1015">Spore dokumentversjon</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/redlining_doccompare.html">Samanlikna versjonar av eit dokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/redlining_docmerge.html">Fletta versjonar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/redlining_enter.html">Registrera endringar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/redlining.html">Registrera og visa endringar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/redlining_accept.html">Godta eller avvisa endringar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/redlining_versions.html">Versjonshandtering</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1016"><label for="1016">Etikettar og visittkort</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/labels.html">Laga og skriva ut etikettar og visittkort</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1018"><label for="1018">Innsetjing av eksterne data</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/copytable2application.html">Setja inn data frå rekneark</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/copytext2application.html">Setja inn data frå tekstdokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/insert_bitmap.html">Setja inn, redigera og lagra punktbilete</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/dragdrop_gallery.html">Leggja til bilete i galleriet</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1019"><label for="1019">Automatiske funksjonar</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/autocorr_url.html">Slå av automatisk nettadresse-gjenkjenning</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1020"><label for="1020">Søk og erstatt</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/data_search2.html">Søke med skjemafilter</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_search.html">Søking i tabellar og skjemadokument</a></li>\
    <li><a target="_top" href="nn/text/shared/01/02100001.html">Liste over regulære uttrykk</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="1021"><label for="1021">Hjelpelinjer</label><ul>\
    <li><a target="_top" href="nn/text/shared/guide/linestyles.html">Bruka linjestilar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/text_color.html">Endra tekstfargen</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/change_title.html">Gje ny tittel til eit dokument</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/round_corner.html">Laga avrunda hjørne</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/background.html">Velja bakgrunnsfargar eller bakgrunnsbilete</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/lineend_define.html">Definera linjesluttar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/linestyle_define.html">Definera linjestilar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/insert_graphic_drawit.html">Redigera biletobjekt</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/line_intext.html">Teikna linjer i tekst</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/aaa_start.html">Dei første stega</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/gallery_insert.html">Setja inn objekt frå galleriet</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/space_hyphen.html">Setja inn harde mellomrom, bindestrekar og mjuke bindestrakar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/insert_specialchar.html">Setja inn spesialteikn</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/tabs.html">Setja inn og redigera tabulatorar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/protection.html">Verna innhald i LibreOffice</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/redlining_protect.html">Verna postar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/pageformat_max.html">Merkja det største utskriftsområdet på ei side</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/measurement_units.html">Velja måleeiningar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/language_select.html">Velja språk for dokumentet</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_tabledefine.html">Tabellutforming</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/numbering_stop.html">Slå av punktmerking og nummerering i enkelte avsnitt</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="09"><label for="09">Databasefunksjonar (Base)</label><ul>\
    <li><input type="checkbox" id="0901"><label for="0901">Generell informasjon</label><ul>\
    <li><a target="_top" href="nn/text/shared/explorer/database/main.html">LibreOffice Database</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/database_main.html">Databaseoversikt</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_new.html">Laga ein ny database</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_tables.html">Arbeida med tabellar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_queries.html">Arbeida med spørjingar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_forms.html">Arbeida med skjema</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_reports.html">Laga rapportar</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_register.html">Registrera og sletta ein database</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_im_export.html">Importera og eksportera data i Base</a></li>\
    <li><a target="_top" href="nn/text/shared/guide/data_enter_sql.html">Køyra SQL-kommandoar</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="04"><label for="04">Presentasjonar og teikning (Impress/Draw)</label><ul>\
    <li><input type="checkbox" id="0401"><label for="0401">Generell informasjon og bruk av brukargrensesnittet</label><ul>\
    <li><a target="_top" href="nn/text/simpress/main0000.html">Velkommen til hjelp for LibreOffice Impress</a></li>\
    <li><a target="_top" href="nn/text/sdraw/main0000.html">Velkommen til hjelp for LibreOffice Draw</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0503.html">Funksjonalitet i LibreOffice Impress</a></li>\
    <li><a target="_top" href="nn/text/sdraw/main0503.html">Funksjonar i LibreOffice Draw</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/keyboard.html">Bruk av snøggtastar i LibreOffice Impress</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/keyboard.html">Snartastar for teikneobjekt</a></li>\
    <li><a target="_top" href="nn/text/simpress/04/01020000.html">Snøggtastar for LibreOffice Impress</a></li>\
    <li><a target="_top" href="nn/text/simpress/04/presenter.html">Tastatursnarvegar i presentasjonskonsollen</a></li>\
    <li><a target="_top" href="nn/text/sdraw/04/01020000.html">Snartastar for teikningar</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/main.html">Hjelp til bruk av LibreOffice Impress</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/main.html">Hjelp til bruk av LibreOffice Draw</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0402"><label for="0402">Kommando og menyreferanse</label><ul>\
    <li><input type="checkbox" id="040201"><label for="040201">Presentasjonar (LibreOffice Impress)</label><ul>\
    <li><input type="checkbox" id="04020101"><label for="04020101">Menyar</label><ul>\
    <li><a target="_top" href="nn/text/simpress/main0100.html">Menyar</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0101.html">Fil</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0102.html">Rediger</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0103.html">Vis</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0104.html">Set inn</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0105.html">Format</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0117.html">Lysbilete</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0114.html">Lysbiletframvising</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0106.html">Verktøy</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0107.html">Vindauge</a></li>\
    <li><a target="_top" href="nn/text/shared/main0108.html">Hjelp</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020102"><label for="04020102">Verktøylinjer</label><ul>\
    <li><a target="_top" href="nn/text/simpress/main0200.html">Verktøylinjer</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0202.html">Verktøylinja for linje og fyll</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0203.html">Tekstformateringslinja</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0204.html">Verktøylinja for lysbiletvising</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0206.html">Statuslinja</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0209.html">Linjalar</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0210.html">Teiknelinja</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0211.html">Disposisjonslinja</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0212.html">Lysbiletsorteringslinja</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0213.html">Innstillingslinja</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0214.html">Biletlinje</a></li>\
    <li><a target="_top" href="nn/text/shared/main0201.html">Standardlinje</a></li>\
    <li><a target="_top" href="nn/text/shared/main0213.html">Navigasjonslinja for skjema</a></li>\
    <li><a target="_top" href="nn/text/shared/main0226.html">Verktøylinja for skjemautforming</a></li>\
    <li><a target="_top" href="nn/text/shared/main0227.html">Punktredigeringslinja</a></li>\
                 </ul></li>\
             </ul></li>\
    <li><input type="checkbox" id="040202"><label for="040202">Teikningar (LibreOffice Draw)</label><ul>\
    <li><input type="checkbox" id="04020201"><label for="04020201">Menyar</label><ul>\
    <li><a target="_top" href="nn/text/sdraw/main0100.html">Menyar</a></li>\
    <li><a target="_top" href="nn/text/sdraw/main0101.html">Fil</a></li>\
    <li><a target="_top" href="nn/text/sdraw/main0102.html">Rediger</a></li>\
    <li><a target="_top" href="nn/text/sdraw/main0103.html">Vis</a></li>\
    <li><a target="_top" href="nn/text/sdraw/main0104.html">Set inn</a></li>\
    <li><a target="_top" href="nn/text/sdraw/main0105.html">Format</a></li>\
    <li><a target="_top" href="nn/text/sdraw/main0106.html">Verktøy</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0113.html">Endra</a></li>\
    <li><a target="_top" href="nn/text/simpress/main0107.html">Vindauge</a></li>\
    <li><a target="_top" href="nn/text/shared/main0108.html">Hjelp</a></li>\
                 </ul></li>\
    <li><input type="checkbox" id="04020202"><label for="04020202">Verktøylinjer</label><ul>\
    <li><a target="_top" href="nn/text/sdraw/main0200.html">Verktøylinjer</a></li>\
    <li><a target="_top" href="nn/text/sdraw/main0210.html">Teiknelinja</a></li>\
    <li><a target="_top" href="nn/text/sdraw/main0213.html">Innstillingslinja</a></li>\
    <li><a target="_top" href="nn/text/shared/main0201.html">Standardlinje</a></li>\
    <li><a target="_top" href="nn/text/shared/main0213.html">Navigasjonslinja for skjema</a></li>\
    <li><a target="_top" href="nn/text/shared/main0226.html">Verktøylinja for skjemautforming</a></li>\
    <li><a target="_top" href="nn/text/shared/main0227.html">Punktredigeringslinja</a></li>\
                 </ul></li>\
             </ul></li>\
         </ul></li>\
    <li><input type="checkbox" id="0403"><label for="0403">Innlasting, lagring, importera og eksportera</label><ul>\
    <li><a target="_top" href="nn/text/simpress/guide/html_export.html">Lagra ein presentasjon i HTML-format</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/html_import.html">Importera HTML-sider inn i presentasjonar</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/palette_files.html">Lasting av farge-, fargeovergang- og skraveringslister</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/animated_gif_save.html">Eksportera animasjonar i GIF-format</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/table_insert.html">Setja inn rekneark i lysbilete</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/graphic_insert.html">Setja inn bilete</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/page_copy.html">Kopiera lysbilete frå andre presentasjonar</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0404"><label for="0404">Formatering</label><ul>\
    <li><a target="_top" href="nn/text/simpress/guide/palette_files.html">Lasting av farge-, fargeovergang- og skraveringslister</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/line_arrow_styles.html">Henting av linje- og pilstilar</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/color_define.html">Bland eigne fargar</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/gradient.html">Laga fargeovergangsfyll</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/eyedropper.html">Byta ut fargar</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/align_arrange.html">Stilla opp, justera og fordela objekt</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/background.html">Endra bakgrunn for lysbiletet</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/footer.html">Legg ein topptekst eller botntekst til alle lysbileta</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/masterpage.html">Bruka eit lysbiletoppsett på eit hovudlysbilete</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/move_object.html">Flytta objekt</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0405"><label for="0405">Utskriving</label><ul>\
    <li><a target="_top" href="nn/text/simpress/guide/printing.html">Utskriving av presentasjonar</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/print_tofit.html">Utskriving av eit lysbilete som er tilpassa ein papirstorleik</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0406"><label for="0406">Effektar</label><ul>\
    <li><a target="_top" href="nn/text/simpress/guide/animated_gif_save.html">Eksportera animasjonar i GIF-format</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/animated_objects.html">Animera objekt i lysbiletpresentasjonar</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/animated_slidechange.html">Animering av lysbiletovergangar</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/cross_fading.html">Overgangstoning mellom to objekt</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/animated_gif_create.html">Slik lagar du animerte GIF-bilete</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0407"><label for="0407">Objekt, bilete og punktbilete</label><ul>\
    <li><a target="_top" href="nn/text/sdraw/guide/combine_etc.html">Slå saman objekt og laga former</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/draw_sector.html">Teikna sektorar og segment</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/duplicate_object.html">Laga kopiar av objekt</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/rotate_object.html">Snu objekt</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/join_objects3d.html">Slå saman 3D-objekt</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/join_objects.html">Kopla saman linjer</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/text2curve.html">Omgjering av tekstteikn til teikneobjekt</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/vectorize.html">Gjera om bilete til vektorgrafikk</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/3d_create.html">Omgjering av 2D-objekt til kurver, mangekantar og 3D-objekt</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/line_arrow_styles.html">Henting av linje- og pilstilar</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/line_draw.html">Teikna kurver</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/line_edit.html">Redigera kurver</a></li>\
    <li><a target="_top" href="nn/text/sdraw/guide/graphic_insert.html">Setja inn bilete</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/table_insert.html">Setja inn rekneark i lysbilete</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/move_object.html">Flytta objekt</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/select_object.html">Merking av underliggjande objekt</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/orgchart.html">Slik lagar du eit flytdiagram</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0408"><label for="0408">Grupper og lag</label><ul>\
    <li><a target="_top" href="nn/text/sdraw/guide/groups.html">Gruppera objekt</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/layers.html">Om lag</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/layer_new.html">Setja inn lag</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/layer_tipps.html">Arbeida med lag</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/layer_move.html">Flytte objekt til eit anna lag</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0409"><label for="0409">Tekst i presentasjonar og teikningar</label><ul>\
    <li><a target="_top" href="nn/text/sdraw/guide/text_enter.html">Leggja til tekst</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/text2curve.html">Omgjering av tekstteikn til teikneobjekt</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0410"><label for="0410">Vising</label><ul>\
    <li><a target="_top" href="nn/text/simpress/guide/arrange_slides.html">Endra rekkjefølgja for lysbileta</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/change_scale.html">Forstørre med tastaturet</a></li>\
         </ul></li>\
    <li><input type="checkbox" id="0411"><label for="0411">Lysbiletframvisingar</label><ul>\
    <li><a target="_top" href="nn/text/simpress/guide/show.html">Visa ei lysbiletframvising</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/presenter_console.html">Bruk av presentasjonskonsollen</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/impress_remote.html">Vegvisar for fjernstyring av Impress</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/individual.html">Laga ei tilpassa lysbiletframvising</a></li>\
    <li><a target="_top" href="nn/text/simpress/guide/rehearse_timings.html">Øv på tidsbruk og lysbiletskift</a></li>\
         </ul></li>\
     </ul></li></ul>\
    <ul><li><input type="checkbox" id="03"><label for="03">Formlar (Math)</label><ul>\
    <li><input type="checkbox" id="0301"><label for="0301">Generell informasjon og bruk av brukargrensesnittet</label><ul>\
    <li><a target="_top" href="nn/text/smath/main0000.html">Velkommen til hjelp for LibreOffice Math</a></li>\
    <li><a target="_top" href="nn/text/smath/main0503.html">Funksjonar i LibreOffice Math</a></li>\
    <li><a target="_top" href="nn/text/smath/guide/main.html">Hjelp til bruk av LibreOffice Math</a></li>\
    <li><a target="_top" href="nn/text/smath/guide/keyboard.html">Snøggtastar (tilgjenge i LibreOffice Math)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0302"><label for="0302">Kommando og menyreferanse</label><ul>\
    <li><a target="_top" href="nn/text/smath/main0100.html">Menyar</a></li>\
    <li><a target="_top" href="nn/text/smath/main0200.html">Verktøylinjer</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0303"><label for="0303">Arbeida med formlar</label><ul>\
    <li><a target="_top" href="nn/text/smath/guide/align.html">Justera formeldelar manuelt</a></li>\
    <li><a target="_top" href="nn/text/smath/guide/attributes.html">Endra standardeigenskapane</a></li>\
    <li><a target="_top" href="nn/text/smath/guide/brackets.html">Slå saman formeldelar i parentesar</a></li>\
    <li><a target="_top" href="nn/text/smath/guide/comment.html">Skriva inn kommentarar</a></li>\
    <li><a target="_top" href="nn/text/smath/guide/newline.html">Setja inn linjeskift</a></li>\
    <li><a target="_top" href="nn/text/smath/guide/parentheses.html">Setja inn parentesar</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="02"><label for="02">Tekstdokument (Writer)</label><ul>\
    <li><input type="checkbox" id="0201"><label for="0201">Generell informasjon og bruk av brukargrensesnittet</label><ul>\
    <li><a target="_top" href="nn/text/swriter/main0000.html">Velkommen til hjelp for LibreOffice Writer</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0503.html">Funksjonalitet i LibreOffice Writer</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/main.html">Hjelp til bruk av LibreOffice Writer</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/resize_navigator.html">Festa og endra storleik på vindauge</a></li>\
    <li><a target="_top" href="nn/text/swriter/04/01020000.html">Snøggtastar i LibreOffice Writer</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/words_count.html">Telje ord</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/keyboard.html">Bruka snøggtastar (tilgjenge i LibreOffice Writer)</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0202"><label for="0202">Kommando og menyreferanse</label><ul>\
    <li><input type="checkbox" id="020201"><label for="020201">Menyar</label><ul>\
    <li><a target="_top" href="nn/text/swriter/main0100.html">Menyar</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0101.html">Fil</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0102.html">Rediger</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0103.html">Vis</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0104.html">Set inn</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0105.html">Format</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0115.html">Stilar</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0110.html">Tabell</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0120.html">Skjemameny</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0106.html">Verktøy</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0107.html">Vindauge</a></li>\
    <li><a target="_top" href="nn/text/shared/main0108.html">Hjelp</a></li>\
			</ul></li>\
    <li><input type="checkbox" id="020202"><label for="020202">Verktøylinjer</label><ul>\
    <li><a target="_top" href="nn/text/swriter/main0200.html">Verktøylinjer</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0202.html">Formateringslinja</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0203.html">Biletlinje</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0204.html">Verktøylinja «Tabell»</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0205.html">Verktøylinja «Eigenskapar for teikneobjekt»</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0206.html">Verktøylinja for punkt og nummerering</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0208.html">Statuslinja</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0210.html">Førehandsvising</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0213.html">Linjalar</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0214.html">Formellinja</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0215.html">Rammelinja</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0216.html">OLE-objektlinja</a></li>\
    <li><a target="_top" href="nn/text/swriter/main0220.html">Tekstobjektlinja</a></li>\
    <li><a target="_top" href="nn/text/shared/main0201.html">Standardlinje</a></li>\
    <li><a target="_top" href="nn/text/shared/main0212.html">Tabelldatalinja</a></li>\
    <li><a target="_top" href="nn/text/shared/main0213.html">Navigasjonslinja for skjema</a></li>\
    <li><a target="_top" href="nn/text/shared/main0214.html">Verktøylinja for spørjingsutforming</a></li>\
    <li><a target="_top" href="nn/text/shared/main0226.html">Verktøylinja for skjemautforming</a></li>\
    <li><a target="_top" href="nn/text/swriter/librelogo/LibreLogo.html">Verktøylinja LibreLogo</a></li>\
			</ul></li>\
		</ul></li>\
    <li><input type="checkbox" id="0203"><label for="0203">Å opprette tekstdokument</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/text_nav_keyb.html">Navigera og merkja med tastaturet</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/text_direct_cursor.html">Bruka direkte skrivemerke</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0204"><label for="0204">Grafikk i tekstdokument</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/insert_graphic.html">Setja inn bilete</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/insert_graphic_dialog.html">Setja inn bilete frå ei fil</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/insert_graphic_gallery.html">Setja inn bilete frå galleriet med dra og slepp</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/insert_graphic_scan.html">Setja inn eit innskanna bilete</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/insert_graphic_fromchart.html">Setja inn eit Calc-diagram i eit tekstdokument</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/insert_graphic_fromdraw.html">Setja inn bilete frå LibreOffice Draw eller Impress</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0205"><label for="0205">Tabellar i tekstdokument</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/number_date_conv.html">Slå av eller på talgjenkjenning i tabellar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/tablemode.html">Endra rader og kolonnar med tastaturet</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/table_delete.html">Sletta tabellar eller innhaldet i ein tabell</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/table_insert.html">Setja inn tabellar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/table_repeat_multiple_headers.html">Gjenta ei tabelloverskrift på ei ny side</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/table_sizing.html">Endra rad- og kolonnestorleik i ein teksttabell</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/table_cells.html">Leggja til eller sletta ei rad eller ein kolonne i ein tabell ved å bruka tastaturet</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0206"><label for="0206">Objekt i tekstdokument</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/anchor_object.html">Plassera objekt</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/wrap.html">Tekstbryting rundt objekt</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0207"><label for="0207">Bolkar og rammer i tekstdokument</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/sections.html">Bruka bolkar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/text_frame.html">Setja inn, redigera og kopla tekstrammer</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/section_edit.html">Redigera bolkar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/section_insert.html">Setja inn bolkar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0208"><label for="0208">Innhaldsliste og register</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/chapter_numbering.html">Kapittelnummerering</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/indices_userdef.html">Tilpassa register</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/indices_toc.html">Laga ei innhaldsliste</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/indices_index.html">Laga alfabetiske register</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/indices_multidoc.html">Register som dekkjer fleire dokument</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/indices_literature.html">Laga ei litteraturliste</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/indices_delete.html">Redigera og fjerna stikkord i register og innhaldslister</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/indices_edit.html">Oppdatera, redigera og sletta register og innhaldslister</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/indices_enter.html">Laga stikkord/oppføringar i register eller innhaldslister</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/indices_form.html">Formatera eit register eller ei innhaldsliste</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0209"><label for="0209">Felt i tekstdokument</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/fields.html">Om felt</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/fields_date.html">Setja inn eit fast eller variabelt datofelt</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/field_convert.html">Gjera eit felt om til tekst</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0210"><label for="0210">Navigera i tekstdokument</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/dragdroptext.html">Flytta og kopiera tekst i dokument</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/arrange_chapters.html">Omorganisera eit dokument ved å bruka «Dokumentstruktur»</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/hyperlinks.html">Setja inn hyperlenkjer frå Dokumentstrukturen</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/navigator.html">Dokumentstrukturen i tekstdokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0211"><label for="0211">Rekning i tekstdokument</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/calculate_multitable.html">Rekning på tvers av tabellar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/calculate.html">Rekning i tekstdokument</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/calculate_clipboard.html">Rekna ut og lima inn resultatet av ein formel i eit tekstdokument</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/calculate_intable.html">Rekna ut summar i tabellar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/calculate_intext.html">Rekna ut avanserte formlar i tekstdokument</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/calculate_intext2.html">Visa resultatet av ei tabellutrekning i ein annan tabell</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0212"><label for="0212">Formatering av tekstdokument</label><ul>\
    <li><input type="checkbox" id="021201"><label for="021201">Malar og stilar</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/templates_styles.html">Malar og stilar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/even_odd_sdw.html">Ulike sidestilar på par- og oddetalssider</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/change_header.html">Laga ein sidestil basert på den gjeldande sida</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/load_styles.html">Bruka stilar frå eit anna dokument eller ein annan mal</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/stylist_fromselect.html">Oppretta nye stilar frå utval</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/stylist_update.html">Oppdatera stilar frå utval</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/template_create.html">Laga ein dokumentmal</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/template_default.html">Endra standardmalen</a></li>\
			</ul></li>\
    <li><a target="_top" href="nn/text/swriter/guide/pageorientation.html">Endra sideretning (liggjande eller ståande)</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/text_capital.html">Byta til store/små bokstavar i ein tekst</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/hidden_text.html">Gøyma tekst</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/header_pagestyles.html">Laga ulike topp- og botntekstar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/header_with_chapter.html">Setja inn kapittelnamn og -nummer i ein topp- eller botntekst</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/shortcut_writing.html">Bruka tekstformatering medan du skriv</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/reset_format.html">Nullstilla skrifteigenskapar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/stylist_fillformat.html">Bruka stilar i fyllformatmodus</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/wrap.html">Tekstbryting rundt objekt</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/text_centervert.html">Bruka ei ramme for å midtstilla teksten på ei side</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/text_emphasize.html">Utheva tekst</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/text_rotate.html">Rotera tekst</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/page_break.html">Setja inn og fjerna sideskift</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/pagestyles.html">Laga og bruka sidestilar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/subscript.html">Heva og senka tekst</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0213"><label for="0213">Spesielle tekstelement</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/captions.html">Bruka forklaringar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/conditional_text.html">Vilkårstekst</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/conditional_text2.html">Vilkårstekst for sideteljing</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/fields_date.html">Setja inn eit fast eller variabelt datofelt</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/fields_enter.html">Leggja til innlister</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/footer_nextpage.html">Setja inn sidetal til komande sider</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/footer_pagenumber.html">Setja inn sidetal i botntekstar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/hidden_text.html">Gøyma tekst</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/header_pagestyles.html">Laga ulike topp- og botntekstar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/header_with_chapter.html">Setja inn kapittelnamn og -nummer i ein topp- eller botntekst</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/fields_userdata.html">Spørja etter brukarinformasjon i felt eller vilkår</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/footnote_usage.html">Setja inn og redigera fotnotar og sluttnotar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/footnote_with_line.html">Avstand mellom fotnotar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/header_footer.html">Om topp- og botntekstar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/header_with_line.html">Formatera topp- og botntekstar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/text_animation.html">Tekstanimasjon</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/form_letters_main.html">Laga eit fletta brev</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0214"><label for="0214">Automatiske funksjonar</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/autocorr_except.html">Leggja til unntak i lista over autorettingar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/autotext.html">Bruka autotekst</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/auto_numbering.html">Laga nummererte lister og punktlister medan du skriv</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/auto_off.html">Slå av autoretting</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/auto_spellcheck.html">Automatisk stavekontroll</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/number_date_conv.html">Slå av eller på talgjenkjenning i tabellar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/using_hyphen.html">Orddeling</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0215"><label for="0215">Nummerering og lister</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/captions_numbers.html">Leggja kapittelnummer til i forklaringar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/auto_numbering.html">Laga nummererte lister og punktlister medan du skriv</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/chapter_numbering.html">Kapittelnummerering</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/insert_tab_innumbering.html">Endra disposisjonsnivået i nummererte lister og punktlister</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/join_numbered_lists.html">Slå saman nummererte lister</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/numbering_lines.html">Leggja til linjenummer</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/numbering_paras.html">Endra nummereringa i ei nummerert liste</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/number_sequence.html">Oppgje talfølgjer</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/using_numbered_lists2.html">Leggja til nummerering</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/using_numbering.html">Nummerering og nummereringsstilar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/using_numbered_lists.html">Leggja til ei punktliste</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0216"><label for="0216">Stavekontroll, synonymordbok og språk</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/auto_spellcheck.html">Automatisk stavekontroll</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/delete_from_dict.html">Fjerna ord frå eigne ordlister</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/using_thesaurus.html">Synonymordbok</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/spellcheck_dialog.html">Kontrollera staving og grammatikk</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0218"><label for="0218">Feilsøking</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/insert_beforetable.html">Setja inn tekst før ein tabell øvst på ei side</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/jump2statusbar.html">Gå til eit visst bokmerke</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0219"><label for="0219">Innlasting, lagring, importera og eksportera</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/send2html.html">Lagra tekstdokument i HTML-format</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/textdoc_inframe.html">Setja inn eit heilt tekstdokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0220"><label for="0220">Hovuddokument</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/globaldoc.html">Hovuddokument og underdokument</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0221"><label for="0221">Lenkjer og referansar</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/references.html">Setja inn kryssreferansar</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/hyperlinks.html">Setja inn hyperlenkjer frå Dokumentstrukturen</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0222"><label for="0222">Utskriving</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/printer_tray.html">Val av papirkjelde</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/print_preview.html">Førehandsvisa ei side før utskrift</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/print_small.html">Skriva ut fleire sider på kvart ark</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/pagestyles.html">Laga og bruka sidestilar</a></li>\
		</ul></li>\
    <li><input type="checkbox" id="0223"><label for="0223">Søk og erstatt</label><ul>\
    <li><a target="_top" href="nn/text/swriter/guide/search_regexp.html">Bruka jokerteikn i tekstsøk</a></li>\
    <li><a target="_top" href="nn/text/shared/01/02100001.html">Liste over regulære uttrykk</a></li>\
		</ul></li>\
	</ul></li></ul>\
    <ul><li><input type="checkbox" id="06"><label for="06">HTML-dokument (Writer)</label><ul>\
    <li><a target="_top" href="nn/text/shared/07/09000000.html">Vevsider</a></li>\
    <li><a target="_top" href="nn/text/shared/02/01170700.html">HTML-filter og skjema</a></li>\
    <li><a target="_top" href="nn/text/swriter/guide/send2html.html">Lagra tekstdokument i HTML-format</a></li>\
	</ul></li></ul>\
';
